| Title: | Create Quarto documentation for R files from comments |
|---|---|
| Description: | Generate R documentation in Quarto format based on comments in code files. |
| Authors: | Daniel Gurgel [aut, cre] |
| Maintainer: | Daniel Gurgel <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.46 |
| Built: | 2026-05-13 09:40:56 UTC |
| Source: | https://github.com/daniellga/rdocs |